@@ -1,6 +1,6 @@
 /*
  * Fisoco : FInd, Select, Order and COnvert files
- * Copyright 2015-2016 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
+ * Copyright 2015-2016-2017 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
  *
  * This file is part of Fisoco.
  *
@@ -54,10 +54,11 @@ public:
 			 std::string search,
 			 std::string dir, Cli* caller);
   bool has_stopped ();
-  std::list<std::string> extr_files (std::string search,
-                                     std::list<std::string> rs, std::string dr);
+  static std::list<std::string> extr_files (std::string search,
+					    std::list<std::string> rs,
+					    std::string dr);
   std::list<std::string> extr_dirs (std::list<std::string> rs, std::string dr);
-  std::string get_type (std::string file, std::string dir);
+  static std::string get_type (std::string file, std::string dir);
   
 private:
     bool search_shall_stop;
