@@ -1,6 +1,6 @@
 /*
  * Fisoco : FInd, Select, Order and COnvert files
- * Copyright 2015-2016 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
+ * Copyright 2015-2016-2017 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
  *
  * This file is part of Fisoco.
  *
@@ -52,20 +52,22 @@ Search::has_stopped ()
 void
 Search::do_work (Cli* caller)
 {
-    if (!search_shall_stop)
+  std::string dir, search_term;
+  std::list<std::string> results;
+  if (!search_shall_stop)
     {
-      std::string search_term = caller->get_search_term ();
-      std::string dir = caller->get_dir_term ();
+      dir = caller->get_dir_term ();
+      search_term = caller->get_search_term ();
       if (search_term.length () == 0)
 	error (gettext ("No search keywords given !"));
-      std::list<std::string> results = getdir (search_term, dir);
+      results = getdir (search_term, dir);
       if (results.size () == 0)
-	error (gettext ("This directory doesn't exists or is unreadable..."));
+	error (gettext ("No results !"));
       else
 	recursive_search (results, search_term, dir, caller);
       caller->search_finished ();
     }
-    else
+  else
     {
       search_shall_stop = false;
       search_has_stopped = true;
@@ -76,64 +78,68 @@ void
 Search::recursive_search (std::list<std::string> results,
 			  std::string search, std::string dir, Cli* caller)
 {
-    std::list<std::string> files = extr_files (search, results, dir);
-    if (files.size () != 0)
+  std::list<std::string> files = extr_files (search, results, dir);
+  if (files.size () != 0)
     {
       caller->notify (files, dir);
     }
-    std::list<std::string> directories = extr_dirs (results, dir);
-    if (directories.size() > 0 && !search_shall_stop)
+  std::list<std::string> directories = extr_dirs (results, dir);
+  if (directories.size() > 0 && !search_shall_stop)
     {
-        for (std::list<std::string>::iterator d = directories.begin ();
-             d != directories.end (); ++d)
-             {
-                 std::string path = (dir != "/" ) ? (dir + "/" + *d) : (dir + *d);
-                 std::list<std::string> new_results  = getdir (search, path);
-                 recursive_search (new_results, search, path, caller);
-             }
+      for (std::string d : directories)
+	{
+	  std::string path = (dir != "/" ) ? (dir + "/" + d) : (dir + d);
+	  std::list<std::string> new_results  = getdir (search, path);
+	  recursive_search (new_results, search, path, caller);
+	}
     }
 }
 
 std::list<std::string>
 Search::getdir (std::string search, std::string dir)
 {
-    std::list<std::string> files;
-    DIR *dp;
-    struct dirent *dirp;
-    dir = (dir == "") ? "/" : dir;
-    if ((dp = opendir (dir.c_str ())) != NULL)
-      while ((dirp = readdir (dp)) != NULL)
-	files.push_back (dirp->d_name);
-    closedir (dp);
-    return files;
+  std::list<std::string> files;
+  DIR *dp;
+  struct dirent *dirp;
+  dir = (dir == "") ? "/" : dir;
+  if ((dp = opendir (dir.c_str ())) != NULL)
+    while ((dirp = readdir (dp)) != NULL)
+      files.push_back (dirp->d_name);
+  closedir (dp);
+  return files;
 }
 
 std::list<std::string>
 Search::extr_files (std::string search, std::list<std::string> res, std::string dir)
 {
-    std::list<std::string> files;
-    for (std::list<std::string>::iterator file = res.begin (); file != res.end (); ++file)
+  std::list<std::string> files;
+  for (std::string file : res)
     {
-        if (get_type(*file, dir) == "File" &&
-            (std::search (file->begin (), file->end (), 
-                          search.begin (), search.end () ) != file->end () ))
-            files.push_back (*file);
+      if (file[0] == '/')
+	file = file.substr (1);
+      if (get_type (file, dir) == "File" &&
+	  (std::search (file.begin (), file.end (), 
+			search.begin (), search.end () ) != file.end () ))
+	files.push_back (file);
     }
-    return files;
+  return files;
 }
 
 std::list<std::string>
 Search::extr_dirs (std::list<std::string> res, std::string pdir)
 {
-    std::list<std::string> dirs;
-    for (std::list<std::string>::iterator dir = res.begin (); dir != res.end (); ++dir)
+  std::list<std::string> dirs;
+  for (std::string dir : res)
     {
-        if ((dir->back() != '.') &&             // We need this for the moment, because
-            get_type(*dir, pdir) == "Directory" && *dir != "proc" && *dir != "sys") // '/proc/*' and '/sys/*'
-                                                // contains a lot of junk
-            dirs.push_back (*dir);              // and we don't know how to manage it...
+      // TODO
+      // Find a way to process /proc & /sys
+      if ((dir.back () != '.')
+	  && get_type (dir, pdir) == "Directory"
+	  && dir != "proc"
+	  && dir != "sys")
+	dirs.push_back (dir);
     }
-    return dirs;
+  return dirs;
 }
 
 std::string
